summaryrefslogtreecommitdiffstats
path: root/amarok/src/engine
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:16 -0600
commit2d3d921590b44ae1e8864104f3e36d022bec0308 (patch)
treea3c17b3a19ac6a26cddd8c0705bf55ff8f46665a /amarok/src/engine
parent6fd8dcd450a39343afe010a50dd0956eb4184540 (diff)
downloadamarok-2d3d921590b44ae1e8864104f3e36d022bec0308.tar.gz
amarok-2d3d921590b44ae1e8864104f3e36d022bec0308.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'amarok/src/engine')
-rw-r--r--amarok/src/engine/akode/akode-engine.cpp2
-rw-r--r--amarok/src/engine/helix/helix-configdialog.cpp24
-rw-r--r--amarok/src/engine/helix/helix-engine.cpp10
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-include/common/include/hxcore.h16
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-include/common/include/hxengin.h4
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-include/common/include/hxiids.h4
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h16
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-include/common/include/hxpiids.h2
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-include/common/include/hxresult.h6
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-include/common/include/hxwin.h12
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-sp.cpp2
-rw-r--r--amarok/src/engine/helix/hxplayercontrol.cpp214
-rw-r--r--amarok/src/engine/helix/hxplayercontrol.h4
-rw-r--r--amarok/src/engine/kdemm/kdemmengine.cpp4
-rw-r--r--amarok/src/engine/mas/masengine.cpp2
-rw-r--r--amarok/src/engine/nmm/HostList.cpp10
-rw-r--r--amarok/src/engine/nmm/HostListItem.cpp22
-rw-r--r--amarok/src/engine/nmm/HostListItem.h6
-rw-r--r--amarok/src/engine/nmm/NmmLocation.h2
-rw-r--r--amarok/src/engine/nmm/nmm_configdialog.cpp2
-rw-r--r--amarok/src/engine/nmm/nmm_configdialogbase.ui12
-rw-r--r--amarok/src/engine/nmm/nmm_engine.cpp6
-rw-r--r--amarok/src/engine/nmm/nmm_engine.h2
-rw-r--r--amarok/src/engine/xine/xine-engine.cpp10
-rw-r--r--amarok/src/engine/xine/xineconfigbase.ui26
-rw-r--r--amarok/src/engine/yauap/yauap-engine.cpp2
26 files changed, 211 insertions, 211 deletions
diff --git a/amarok/src/engine/akode/akode-engine.cpp b/amarok/src/engine/akode/akode-engine.cpp
index f2404012..26840589 100644
--- a/amarok/src/engine/akode/akode-engine.cpp
+++ b/amarok/src/engine/akode/akode-engine.cpp
@@ -180,7 +180,7 @@ AkodeEngine::event( TQEvent *e )
case 3002:
m_player->stop();
emit trackEnded();
- emit infoMessage( i18n("Unable to decode <i>%1</i>").tqarg( m_url.prettyURL()) );
+ emit infoMessage( i18n("Unable to decode <i>%1</i>").arg( m_url.prettyURL()) );
break;
default:
diff --git a/amarok/src/engine/helix/helix-configdialog.cpp b/amarok/src/engine/helix/helix-configdialog.cpp
index 73080389..7a88820e 100644
--- a/amarok/src/engine/helix/helix-configdialog.cpp
+++ b/amarok/src/engine/helix/helix-configdialog.cpp
@@ -12,12 +12,12 @@
#include <sys/stat.h>
#include <unistd.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqscrollview.h>
#include <tqspinbox.h>
#include <tqtooltip.h>
-#include <tqtextedit.h>
-#include <tqtextview.h>
+#include <textedit.h>
+#include <textview.h>
#include <tqfileinfo.h>
#include <tqcheckbox.h>
@@ -53,7 +53,7 @@ HelixConfigEntry::HelixConfigEntry( TQWidget *parent,
, m_valueChanged( false )
, m_stringValue( defaultvalue )
{
- TQGridLayout *grid = (TQGridLayout*)parent->tqlayout();
+ TQGridLayout *grid = (TQGridLayout*)parent->layout();
m_w = new KLineEdit( m_stringValue, parent );
connect( (TQWidget *) m_w, TQT_SIGNAL(textChanged( const TQString& )), this, TQT_SLOT(slotStringChanged( const TQString& )) );
@@ -62,7 +62,7 @@ HelixConfigEntry::HelixConfigEntry( TQWidget *parent,
TQToolTip::add( (TQWidget *) m_w, "<qt>" + tooltip );
TQLabel* d = new TQLabel( description + ':', parent );
- d->tqsetAlignment( TQLabel::WordBreak | TQLabel::AlignVCenter );
+ d->setAlignment( TQLabel::WordBreak | TQLabel::AlignVCenter );
grid->addWidget( (TQWidget *) m_w, row, 1 );
grid->addWidget( d, row, 0 );
@@ -79,7 +79,7 @@ HelixConfigEntry::HelixConfigEntry( TQWidget *parent,
, m_valueChanged( false )
, m_stringValue( defaultvalue )
{
- TQGridLayout *grid = (TQGridLayout*)parent->tqlayout();
+ TQGridLayout *grid = (TQGridLayout*)parent->layout();
m_key = str;
@@ -90,7 +90,7 @@ HelixConfigEntry::HelixConfigEntry( TQWidget *parent,
TQToolTip::add( m_w, "<qt>" + tooltip );
TQLabel* d = new TQLabel( description + ':', parent );
- d->tqsetAlignment( TQLabel::WordBreak | TQLabel::AlignVCenter );
+ d->setAlignment( TQLabel::WordBreak | TQLabel::AlignVCenter );
grid->addWidget( m_w, row, 1 );
grid->addWidget( d, row, 0 );
@@ -110,7 +110,7 @@ HelixSoundDevice::HelixSoundDevice( TQWidget *parent,
HelixEngine *engine )
: deviceComboBox(0), checkBox_outputDevice(0), lineEdit_outputDevice(0), m_changed(false), m_engine(engine)
{
- TQGridLayout *grid = (TQGridLayout*)parent->tqlayout();
+ TQGridLayout *grid = (TQGridLayout*)parent->layout();
deviceComboBox = new KComboBox( false, parent, "deviceComboBox" );
deviceComboBox->insertItem("oss"); // I believe these are not subject to translation (they don't seem to be in xine,
@@ -119,7 +119,7 @@ HelixSoundDevice::HelixSoundDevice( TQWidget *parent,
#endif
deviceComboBox->setCurrentItem(HelixConfig::outputplugin());
TQLabel* op = new TQLabel( i18n("Output plugin:"), parent );
- op->tqsetAlignment( TQLabel::WordBreak | TQLabel::AlignVCenter );
+ op->setAlignment( TQLabel::WordBreak | TQLabel::AlignVCenter );
grid->addWidget( op, row, 0 );
grid->addWidget( deviceComboBox, row, 1);
connect( (TQWidget *)deviceComboBox, TQT_SIGNAL( activated( const TQString& ) ), this, TQT_SLOT( slotNewDevice( const TQString& )) );
@@ -128,7 +128,7 @@ HelixSoundDevice::HelixSoundDevice( TQWidget *parent,
++row;
checkBox_outputDevice = new TQCheckBox( parent, "checkBox_outputDevice" );
- checkBox_outputDevice->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, checkBox_outputDevice->sizePolicy().hasHeightForWidth() ) );
+ checkBox_outputDevice->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, checkBox_outputDevice->sizePolicy().hasHeightForWidth() ) );
grid->addWidget( checkBox_outputDevice, row, 0 );
checkBox_outputDevice->setText( i18n( "Device:" ) );
@@ -276,7 +276,7 @@ HelixConfigDialogBase::HelixConfigDialogBase( HelixEngine *engine, Amarok::Plugi
grid->setColStretch( 1, 1 );
if( sv )
- sv->setMinimumWidth( grid->tqsizeHint().width() + 20 );
+ sv->setMinimumWidth( grid->sizeHint().width() + 20 );
engine->m_coredir = HelixConfig::coreDirectory();
m_core = new HelixConfigEntry( parent, engine->m_coredir,
@@ -349,7 +349,7 @@ HelixConfigDialogBase::HelixConfigDialogBase( HelixEngine *engine, Amarok::Plugi
TQTextEdit *le = new TQTextEdit( parent );
if( sv )
- sv->setMinimumWidth( le->tqsizeHint().width() );
+ sv->setMinimumWidth( le->sizeHint().width() );
grid = new TQGridLayout( parent, /*rows*/1, /*cols*/1, /*margin*/2, /*spacing*/1 );
grid->addMultiCellWidget( le, 0, 1, 0, 1, 0 );
diff --git a/amarok/src/engine/helix/helix-engine.cpp b/amarok/src/engine/helix/helix-engine.cpp
index 7d778741..fb4dc695 100644
--- a/amarok/src/engine/helix/helix-engine.cpp
+++ b/amarok/src/engine/helix/helix-engine.cpp
@@ -126,7 +126,7 @@ void HelixEngine::notifyUser(unsigned long code, const char *moreinfo, const cha
{
TQString *err = HelixErrors::errorText(code);
if (err)
- emit statusText(i18n("Helix Core returned error: %1 %2 %3").tqarg(TQString(*err)).tqarg(TQString(moreinfo)).tqarg(TQString(moreinfourl)));
+ emit statusText(i18n("Helix Core returned error: %1 %2 %3").arg(TQString(*err)).arg(TQString(moreinfo)).arg(TQString(moreinfourl)));
else
emit statusText(i18n("Helix Core returned error: <unknown>"));
}
@@ -135,7 +135,7 @@ void HelixEngine::interruptUser(unsigned long code, const char *moreinfo, const
{
TQString *err = HelixErrors::errorText(code);
if (err)
- emit infoMessage(i18n("Helix Core returned error: %1 %1 %1").tqarg(TQString(*err)).tqarg(TQString(moreinfo)).tqarg(TQString(moreinfourl)));
+ emit infoMessage(i18n("Helix Core returned error: %1 %1 %1").arg(TQString(*err)).arg(TQString(moreinfo)).arg(TQString(moreinfourl)));
else
emit infoMessage(i18n("Helix Core returned error: <unknown>"));
@@ -146,13 +146,13 @@ void HelixEngine::interruptUser(unsigned long code, const char *moreinfo, const
void HelixEngine::onContacting(const char *host)
{
- emit statusText( i18n("Contacting: %1").tqarg( TQString(host) ) );
+ emit statusText( i18n("Contacting: %1").arg( TQString(host) ) );
}
void HelixEngine::onBuffering(int pcnt)
{
if (pcnt != 100) // let's not report that...
- emit statusText( i18n( "Buffering %1%" ).tqarg( pcnt ) );
+ emit statusText( i18n( "Buffering %1%" ).arg( pcnt ) );
}
@@ -289,7 +289,7 @@ HelixEngine::load( const KURL &url, bool isStream )
{
const TQString path = url.path();
const TQString ext = path.mid( path.findRev( '.' ) + 1 ).lower();
- emit statusText( i18n("No plugin found for the %1 format").tqarg(ext) );
+ emit statusText( i18n("No plugin found for the %1 format").arg(ext) );
return false;
}
diff --git a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxengin.h b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxengin.h
index ccbcb0a2..6e0e6cd6 100644
--- a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxengin.h
+++ b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxengin.h
@@ -2252,7 +2252,7 @@ typedef enum
NI_OPER_STATUS_CONNECTING,
NI_OPER_STATUS_CONNECTED,
NI_OPER_STATUS_OPERATIONAL
-} NItqStatus;
+} NIStatus;
typedef enum
{
@@ -2290,7 +2290,7 @@ struct NIInfo
{
NIType type;
IHXBuffer* pDescription;
- NItqStatus status;
+ NIStatus status;
UINT32 ulIPv4Index;
UINT32 ulIPv6Index;
UINT32 ulMTU;
diff --git a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxiids.h b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxiids.h
index 6557e510..883d50e3 100644
--- a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxiids.h
+++ b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxiids.h
@@ -695,10 +695,10 @@ DEFINE_GUID_ENUM(IID_IHXSourceHandler, 0xb2646da0, 0x410a, 0x11d6,
* Description:
* Interfaces related to get pending status from objects
* Interfaces:
- * IHXPendingtqStatus: {00001100-0901-11d1-8B06-00A024406D59}
+ * IHXPendingStatus: {00001100-0901-11d1-8B06-00A024406D59}
*/
#ifndef _HXPENDS_H_
-DEFINE_GUID_ENUM(IID_IHXPendingtqStatus, 0x00001100, 0x901, 0x11d1, 0x8b, 0x6, 0x0, 0xa0, 0x24, 0x40, 0x6d, 0x59)
+DEFINE_GUID_ENUM(IID_IHXPendingStatus, 0x00001100, 0x901, 0x11d1, 0x8b, 0x6, 0x0, 0xa0, 0x24, 0x40, 0x6d, 0x59)
#endif
/*
* File:
diff --git a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h
index 775d287c..e29fe874 100644
--- a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h
+++ b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h
@@ -531,7 +531,7 @@ DECLARE_INTERFACE_(IHXRegistry, IUnknown)
* Returns the count of the number of Properties under the one
* whose name is specified in "pName".
*
- * pName - IN - name of the Property whose number of tqchildren is to be
+ * pName - IN - name of the Property whose number of children is to be
* retrieved
*/
STDMETHOD_(INT32, GetNumPropsByName) (THIS_
@@ -544,7 +544,7 @@ DECLARE_INTERFACE_(IHXRegistry, IUnknown)
* Returns the count of the number of Properties under the one
* whose unique id is specified in "ulId".
*
- * ulId - IN - unique id of the Property whose number of tqchildren is
+ * ulId - IN - unique id of the Property whose number of children is
* to be retrieved
*/
STDMETHOD_(INT32, GetNumPropsById) (THIS_
@@ -1594,7 +1594,7 @@ DECLARE_INTERFACE_(IHXRegistry2, IUnknown)
* Returns the count of the number of Properties under the one
* whose name is specified in "pName".
*
- * pName - IN - name of the Property whose number of tqchildren is to be
+ * pName - IN - name of the Property whose number of children is to be
* retrieved
*/
STDMETHOD_(INT32, GetNumPropsByName) (THIS_
@@ -1607,7 +1607,7 @@ DECLARE_INTERFACE_(IHXRegistry2, IUnknown)
* Returns the count of the number of Properties under the one
* whose unique id is specified in "ulId".
*
- * ulId - IN - unique id of the Property whose number of tqchildren is
+ * ulId - IN - unique id of the Property whose number of children is
* to be retrieved
*/
STDMETHOD_(INT32, GetNumPropsById) (THIS_
@@ -2089,10 +2089,10 @@ DECLARE_INTERFACE_(IHXRegistry2, IUnknown)
* Method:
* IHXRegistry2::GetChildIdListByName
* Purpose:
- * Get a array which enumerates all of the tqchildren under a
+ * Get a array which enumerates all of the children under a
* property by id.
*
- * pName - IN - name of the Property whose tqchildren are to be enumerated.
+ * pName - IN - name of the Property whose children are to be enumerated.
* pValues - OUT - array of unique Property id's.
* ulCount - OUT - size of the returned pValues array.
*
@@ -2108,10 +2108,10 @@ DECLARE_INTERFACE_(IHXRegistry2, IUnknown)
* Method:
* IHXRegistry2::GetChildIdListById
* Purpose:
- * Get a array which enumerates all of the tqchildren under a
+ * Get a array which enumerates all of the children under a
* property by id.
*
- * ulId - IN - unique id of the Property whose tqchildren are to be enumerated.
+ * ulId - IN - unique id of the Property whose children are to be enumerated.
* pValues - OUT - array of unique Property id's.
* ulCount - OUT - size of the returned pValues array.
*
diff --git a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxpiids.h b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxpiids.h
index a436c63e..b3921e04 100644
--- a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxpiids.h
+++ b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxpiids.h
@@ -740,7 +740,7 @@ DEFINE_GUID_ENUM(IID_IHXMMSResendResponse, 0xa581f3a4, 0xc508, 0x4800, 0xba, 0xd
*
*/
DEFINE_GUID_ENUM(IID_IHXDistributedLicenseRequester, 0x00005702, 0x901, 0x11d1, 0x8b, 0x6, 0x0, 0xa0, 0x24, 0x40, 0x6d, 0x59)
-DEFINE_GUID_ENUM(IID_IHXDistributedLicenseRequesttqStatus, 0x00005703, 0x901, 0x11d1, 0x8b, 0x6, 0x0, 0xa0, 0x24, 0x40, 0x6d, 0x59)
+DEFINE_GUID_ENUM(IID_IHXDistributedLicenseRequestStatus, 0x00005703, 0x901, 0x11d1, 0x8b, 0x6, 0x0, 0xa0, 0x24, 0x40, 0x6d, 0x59)
/*
* File: hxauto.h
diff --git a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxresult.h b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxresult.h
index 180c5e5d..e9ce4dcc 100644
--- a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxresult.h
+++ b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxresult.h
@@ -27,8 +27,8 @@ typedef LONG32 HX_RESULT;
# define MAKE_HRESULT(sev,fac,code) \
((HRESULT) (((unsigned long)(sev)<<31) | ((unsigned long)(fac)<<16) | \
((unsigned long)(code))) )
-# define SUCCEEDED(tqStatus) (((unsigned long)(tqStatus)>>31) == 0)
-# define FAILED(tqStatus) (((unsigned long)(tqStatus)>>31) != 0)
+# define SUCCEEDED(Status) (((unsigned long)(Status)>>31) == 0)
+# define FAILED(Status) (((unsigned long)(Status)>>31) != 0)
#else
# ifndef _HRESULT_DEFINED
typedef LONG32 HRESULT;
@@ -120,7 +120,7 @@ typedef LONG32 HX_RESULT;
#define HXR_WM_OPL_NOT_SUPPORTED MAKE_HX_RESULT(1,SS_GLO,36) // 80040024
// $Private:
-/* tqStatus Code for backup/restore*/
+/* Status Code for backup/restore*/
#define HXR_RESTORATION_COMPLETE MAKE_HX_RESULT(1,SS_GLO,27) // 8004001b
#define HXR_BACKUP_COMPLETE MAKE_HX_RESULT(1,SS_GLO,28) // 8004001c
#define HXR_TLC_NOT_CERTIFIED MAKE_HX_RESULT(1,SS_GLO,29) // 8004001d
diff --git a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxwin.h b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxwin.h
index 42afd584..1ccba13b 100644
--- a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxwin.h
+++ b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxwin.h
@@ -614,9 +614,9 @@ DECLARE_INTERFACE_(IHXSiteSupplier, IUnknown)
* Method:
* IHXSiteSupplier::BeginChangeLayout
* Purpose:
- * Called to inform the site supplier a tqlayout change has beginning
+ * Called to inform the site supplier a layout change has beginning
* it can expect to receive SitesNeeded() and SitesNotNeeded() calls
- * while a tqlayout change is in progress,
+ * while a layout change is in progress,
*/
STDTQT_METHOD(BeginChangeLayout) (THIS) PURE;
@@ -624,7 +624,7 @@ DECLARE_INTERFACE_(IHXSiteSupplier, IUnknown)
* Method:
* IHXSiteSupplier::DoneChangeLayout
* Purpose:
- * Called to inform the site supplier the tqlayout change has been
+ * Called to inform the site supplier the layout change has been
* completed.
*/
STDTQT_METHOD(DoneChangeLayout) (THIS) PURE;
@@ -642,7 +642,7 @@ DECLARE_INTERFACE_(IHXSiteSupplier, IUnknown)
*
* Interface implemented by the client core. This interface is called
* by users of the client core to inform it of IHXSite's which are
- * available for tqlayout of renderers
+ * available for layout of renderers
*
* IID_IHXSiteManager:
*
@@ -923,7 +923,7 @@ DECLARE_INTERFACE_(IHXSiteFullScreen, IUnknown)
*
* Purpose:
*
- * Allow tqlayout site groups to be added and removed
+ * Allow layout site groups to be added and removed
*
* IID_IHXLayoutSiteGroupManager:
*
@@ -1091,7 +1091,7 @@ DECLARE_INTERFACE_(IHXStatusMessage, IUnknown)
* IHXStatusMessage methods
*/
- STDTQT_METHOD(SettqStatus) (THIS_ const char* pText) PURE;
+ STDTQT_METHOD(SetStatus) (THIS_ const char* pText) PURE;
};
// $Private:
diff --git a/amarok/src/engine/helix/helix-sp/helix-sp.cpp b/amarok/src/engine/helix/helix-sp/helix-sp.cpp
index 4cb58bb7..41c84a1d 100644
--- a/amarok/src/engine/helix/helix-sp/helix-sp.cpp
+++ b/amarok/src/engine/helix/helix-sp/helix-sp.cpp
@@ -835,7 +835,7 @@ HelixSimplePlayer::~HelixSimplePlayer()
{
tearDown();
- // only now tqinvalidate the device, not whenever we teardown
+ // only now invalidate the device, not whenever we teardown
delete [] m_device;
}
diff --git a/amarok/src/engine/helix/hxplayercontrol.cpp b/amarok/src/engine/helix/hxplayercontrol.cpp
index fabc8a0d..8cb26939 100644
--- a/amarok/src/engine/helix/hxplayercontrol.cpp
+++ b/amarok/src/engine/helix/hxplayercontrol.cpp
@@ -69,7 +69,7 @@ PlayerControl::PlayerControl() : m_eq_enabled(false), m_preamp(0), m_err(0), iam
m_inited(false), m_api( HelixSimplePlayer::OSS ), m_device(0), mimehead(0), mimelistlen(0),
m_numPlugins(0), m_pluginInfo(0)
{
- memset(m_tqchildren, 0, sizeof(m_tqchildren));
+ memset(m_children, 0, sizeof(m_children));
}
PlayerControl::~PlayerControl()
@@ -100,7 +100,7 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
return;
}
- memset(&m_tqchildren, 0, numPlayers * sizeof(struct playerChildren));
+ memset(&m_children, 0, numPlayers * sizeof(struct playerChildren));
m_inited = false;
@@ -121,30 +121,30 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
{
if (pmapped)
{
- m_tqchildren[i].current_time = &(pmapped[i].current_time);
- m_tqchildren[i].duration = &(pmapped[i].duration);
- m_tqchildren[i].md = &(pmapped[i].md);
+ m_children[i].current_time = &(pmapped[i].current_time);
+ m_children[i].duration = &(pmapped[i].duration);
+ m_children[i].md = &(pmapped[i].md);
- m_tqchildren[i].m_current = &(pmapped[i].m_current);
- m_tqchildren[i].m_consumed = &(pmapped[i].m_consumed);
- //m_tqchildren[i].q = pmapped[i].q;
+ m_children[i].m_current = &(pmapped[i].m_current);
+ m_children[i].m_consumed = &(pmapped[i].m_consumed);
+ //m_children[i].q = pmapped[i].q;
//for (int j=0; j<NUM_SCOPEBUFS; j++)
//{
- // m_tqchildren[i].q[j].allocd = false;
- // m_tqchildren[i].q[j].buf = pmapped[i].b[j];
+ // m_children[i].q[j].allocd = false;
+ // m_children[i].q[j].buf = pmapped[i].b[j];
//}
}
- err = pipe(m_tqchildren[i].m_pipeA);
- err |= pipe(m_tqchildren[i].m_pipeB);
+ err = pipe(m_children[i].m_pipeA);
+ err |= pipe(m_children[i].m_pipeB);
if ( !err && (iamparent = fork()) )
{
// parent
print2stderr("%%%%%% parent initializes player %d\n", i);
// parent's m_pid remains 0
- m_tqchildren[i].m_pid = iamparent;
- close(m_tqchildren[i].m_pipeA[1]); // parent uses A for reading
- close(m_tqchildren[i].m_pipeB[0]); // and B for writing
+ m_children[i].m_pid = iamparent;
+ close(m_children[i].m_pipeA[1]); // parent uses A for reading
+ close(m_children[i].m_pipeB[0]); // and B for writing
}
else if (!err)
{
@@ -153,17 +153,17 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
cerr << "%%%%%% child initializes as player " << i << endl;;
m_index = i; // child's index is saved
- close(m_tqchildren[i].m_pipeA[0]); // child uses A for writing
- close(m_tqchildren[i].m_pipeB[1]); // and B for reading
+ close(m_children[i].m_pipeA[0]); // child uses A for writing
+ close(m_children[i].m_pipeB[1]); // and B for reading
break;
}
}
- if (!iamparent) // tqchildren stay here, parents return
+ if (!iamparent) // children stay here, parents return
{
- int rfd = m_tqchildren[m_index].m_pipeB[0];
- int wfd = m_tqchildren[m_index].m_pipeA[1];
+ int rfd = m_children[m_index].m_pipeB[0];
+ int wfd = m_children[m_index].m_pipeA[1];
int n;
struct timeval timeout;
HSPPlayerControlled *player = 0;
@@ -237,7 +237,7 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
if (m_inited)
{
if (pmapped)
- *m_tqchildren[m_index].current_time = 0;
+ *m_children[m_index].current_time = 0;
if (sz == sizeof(unsigned long) + 1)
{
@@ -397,7 +397,7 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
{
player->clearScopeQ(0);
if (pmapped)
- *m_tqchildren[m_index].m_consumed = *m_tqchildren[m_index].m_current = 0;
+ *m_children[m_index].m_consumed = *m_children[m_index].m_current = 0;
}
break;
case TEARDOWN:
@@ -437,36 +437,36 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
playing = false;
if (pmapped)
{
- *m_tqchildren[m_index].current_time = 0;
- *m_tqchildren[m_index].duration = 0;
+ *m_children[m_index].current_time = 0;
+ *m_children[m_index].duration = 0;
}
}
if (pmapped)
{
- *m_tqchildren[m_index].current_time = player->where(0);
- *m_tqchildren[m_index].duration = player->duration(0);
+ *m_children[m_index].current_time = player->where(0);
+ *m_children[m_index].duration = player->duration(0);
HelixSimplePlayer::metaData *md = player->getMetaData(0);
if (md)
- memcpy((void *) m_tqchildren[m_index].md, (void *) md, sizeof(HelixSimplePlayer::metaData));
+ memcpy((void *) m_children[m_index].md, (void *) md, sizeof(HelixSimplePlayer::metaData));
struct DelayQueue *item;
//int j;
while ((item = player->getScopeBuf(0)))
{
- //j = (*m_tqchildren[m_index].m_current + 1) % NUM_SCOPEBUFS;
+ //j = (*m_children[m_index].m_current + 1) % NUM_SCOPEBUFS;
//cerr << "player:" << m_index << " j=" << j << " time=" << item->time << " etime=" << item->etime << " len=" << item->len << endl;
- //m_tqchildren[m_index].q[j].len = item->len;
- //m_tqchildren[m_index].q[j].time = item->time;
- //m_tqchildren[m_index].q[j].etime = item->etime;
- //m_tqchildren[m_index].q[j].nchan = item->nchan;
- //m_tqchildren[m_index].q[j].bps = item->bps;
- //m_tqchildren[m_index].q[j].tps = item->tps;
- //m_tqchildren[m_index].q[j].spb = item->spb;
- //memcpy((void *)m_tqchildren[m_index].q[j].buf, (void *) item->buf, item->len );
- //*m_tqchildren[m_index].m_current = j;
+ //m_children[m_index].q[j].len = item->len;
+ //m_children[m_index].q[j].time = item->time;
+ //m_children[m_index].q[j].etime = item->etime;
+ //m_children[m_index].q[j].nchan = item->nchan;
+ //m_children[m_index].q[j].bps = item->bps;
+ //m_children[m_index].q[j].tps = item->tps;
+ //m_children[m_index].q[j].spb = item->spb;
+ //memcpy((void *)m_children[m_index].q[j].buf, (void *) item->buf, item->len );
+ //*m_children[m_index].m_current = j;
//cerr << "player:" << m_index << " time=" << item->time << " etime=" << item->etime << endl;
sendscopebuf(wfd, item);
delete item;
@@ -488,15 +488,15 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
sendsetdevice();
sendinit();
- // wait for ready from tqchildren
+ // wait for ready from children
while (!done && !dead)
{
dispatch();
done = true;
for (i=0; i<numPlayers; i++)
{
- done &= m_tqchildren[i].isready;
- dead |= m_tqchildren[i].isdead;
+ done &= m_children[i].isready;
+ dead |= m_children[i].isdead;
}
}
@@ -540,12 +540,12 @@ void PlayerControl::tearDown()
{
if (m_inited)
{
- sendteardown(m_tqchildren[i].m_pipeB[1]);
- close(m_tqchildren[i].m_pipeB[1]);
- close(m_tqchildren[i].m_pipeA[0]);
- cerr << "About to waitpid for pid " << m_tqchildren[i].m_pid << endl;
- kill(m_tqchildren[i].m_pid, SIGTERM);
- waitpid(m_tqchildren[i].m_pid, &tmp, 0);
+ sendteardown(m_children[i].m_pipeB[1]);
+ close(m_children[i].m_pipeB[1]);
+ close(m_children[i].m_pipeA[0]);
+ cerr << "About to waitpid for pid " << m_children[i].m_pid << endl;
+ kill(m_children[i].m_pid, SIGTERM);
+ waitpid(m_children[i].m_pid, &tmp, 0);
}
}
}
@@ -553,16 +553,16 @@ void PlayerControl::tearDown()
void PlayerControl::start(int playerIndex, bool fadein, unsigned long fadetime)
{
- m_tqchildren[playerIndex].isplaying = true;
+ m_children[playerIndex].isplaying = true;
if (pmapped)
- *m_tqchildren[playerIndex].m_consumed = *m_tqchildren[playerIndex].m_current = 0;
- sendstart(m_tqchildren[playerIndex].m_pipeB[1], fadein, fadetime);
+ *m_children[playerIndex].m_consumed = *m_children[playerIndex].m_current = 0;
+ sendstart(m_children[playerIndex].m_pipeB[1], fadein, fadetime);
}
int PlayerControl::setURL(const char *url, int playerIndex, bool islocal)
{
- m_tqchildren[playerIndex].islocal = islocal;
- if (sendsetURL(m_tqchildren[playerIndex].m_pipeB[1], url, islocal))
+ m_children[playerIndex].islocal = islocal;
+ if (sendsetURL(m_children[playerIndex].m_pipeB[1], url, islocal))
return 0;
return -1;
@@ -570,7 +570,7 @@ int PlayerControl::setURL(const char *url, int playerIndex, bool islocal)
bool PlayerControl::done(int playerIndex)
{
- return (!m_tqchildren[playerIndex].isplaying);
+ return (!m_children[playerIndex].isplaying);
}
void PlayerControl::stop(int playerIndex)
@@ -582,30 +582,30 @@ void PlayerControl::stop(int playerIndex)
}
else
{
- m_tqchildren[playerIndex].isplaying = false;
- sendstop(m_tqchildren[playerIndex].m_pipeB[1]);
+ m_children[playerIndex].isplaying = false;
+ sendstop(m_children[playerIndex].m_pipeB[1]);
}
}
void PlayerControl::pause(int playerIndex)
{
- sendpause(m_tqchildren[playerIndex].m_pipeB[1]);
+ sendpause(m_children[playerIndex].m_pipeB[1]);
}
void PlayerControl::resume(int playerIndex)
{
- sendresume(m_tqchildren[playerIndex].m_pipeB[1]);
+ sendresume(m_children[playerIndex].m_pipeB[1]);
}
void PlayerControl::seek(unsigned long pos, int playerIndex)
{
- sendmessage(m_tqchildren[playerIndex].m_pipeB[1], SEEK, (unsigned char *) &pos, sizeof(unsigned long));
+ sendmessage(m_children[playerIndex].m_pipeB[1], SEEK, (unsigned char *) &pos, sizeof(unsigned long));
}
unsigned long PlayerControl::where(int playerIndex) const
{
if (pmapped)
- return *m_tqchildren[playerIndex].current_time;
+ return *m_children[playerIndex].current_time;
else
return 0;
}
@@ -613,7 +613,7 @@ unsigned long PlayerControl::where(int playerIndex) const
unsigned long PlayerControl::duration(int playerIndex) const
{
if (pmapped)
- return *m_tqchildren[playerIndex].duration;
+ return *m_children[playerIndex].duration;
else
return 0;
}
@@ -627,7 +627,7 @@ void PlayerControl::setVolume(unsigned long vol)
{
m_volume = vol;
for (int i = 0; i < nNumPlayers; i++)
- sendsetvolume(m_tqchildren[i].m_pipeB[1], vol);
+ sendsetvolume(m_children[i].m_pipeB[1], vol);
}
void PlayerControl::dispatch()
@@ -647,8 +647,8 @@ void PlayerControl::dispatch()
for (i=0; i<nNumPlayers; i++)
{
- rfd = m_tqchildren[i].m_pipeA[0];
- wfd = m_tqchildren[i].m_pipeB[1];
+ rfd = m_children[i].m_pipeA[0];
+ wfd = m_children[i].m_pipeB[1];
FD_SET(rfd, &rdset);
FD_SET(wfd, &wrset); // really should check to see if we can write, but not gonna
if (rfd > n)
@@ -661,8 +661,8 @@ void PlayerControl::dispatch()
ntot = select(n + 1, &rdset, 0, 0, &timeout);
for (i=0; ntot && i < nNumPlayers; i++)
{
- rfd = m_tqchildren[i].m_pipeA[0];
- wfd = m_tqchildren[i].m_pipeB[1];
+ rfd = m_children[i].m_pipeA[0];
+ wfd = m_children[i].m_pipeB[1];
if ( FD_ISSET(rfd, &rdset) )
{
msgid m;
@@ -675,14 +675,14 @@ void PlayerControl::dispatch()
{
case READY:
print2stderr("CHILD %d is READY\n", i);
- m_tqchildren[i].isready = true;;
+ m_children[i].isready = true;;
break;
case DONE:
print2stderr("CHILD %d is DONE\n", i);
if (!sz)
{
- m_tqchildren[i].isplaying = false;
+ m_children[i].isplaying = false;
clearScopeQ(i);
play_finished(i);
}
@@ -852,7 +852,7 @@ void PlayerControl::dispatch()
}
else
{
- m_tqchildren[i].isdead = true;
+ m_children[i].isdead = true;
return; // should never happen
}
}
@@ -860,16 +860,16 @@ void PlayerControl::dispatch()
for (i=0; pmapped && i<nNumPlayers; i++)
{
- while (*m_tqchildren[i].m_consumed != *m_tqchildren[i].m_current)
+ while (*m_children[i].m_consumed != *m_children[i].m_current)
{
- addScopeBuf(&m_tqchildren[i].q[*m_tqchildren[i].m_consumed], i);
+ addScopeBuf(&m_children[i].q[*m_children[i].m_consumed], i);
- //cerr << "j=" << *m_tqchildren[i].m_consumed <<
- // " time=" << m_tqchildren[i].q[*m_tqchildren[i].m_consumed].time <<
- // " etime=" << m_tqchildren[i].q[*m_tqchildren[i].m_consumed].etime <<
- // " len=" << m_tqchildren[i].q[*m_tqchildren[i].m_consumed].len << endl;
+ //cerr << "j=" << *m_children[i].m_consumed <<
+ // " time=" << m_children[i].q[*m_children[i].m_consumed].time <<
+ // " etime=" << m_children[i].q[*m_children[i].m_consumed].etime <<
+ // " len=" << m_children[i].q[*m_children[i].m_consumed].len << endl;
- *m_tqchildren[i].m_consumed = (*m_tqchildren[i].m_consumed + 1) % NUM_SCOPEBUFS;
+ *m_children[i].m_consumed = (*m_children[i].m_consumed + 1) % NUM_SCOPEBUFS;
}
}
}
@@ -881,37 +881,37 @@ void PlayerControl::cleanUpStream(int playerIndex)
bool PlayerControl::isPlaying(int playerIndex) const
{
- return m_tqchildren[playerIndex].isplaying;
+ return m_children[playerIndex].isplaying;
}
bool PlayerControl::isLocal(int playerIndex) const
{
- return m_tqchildren[playerIndex].islocal;
+ return m_children[playerIndex].islocal;
}
void PlayerControl::setFadeout(bool fadeout, unsigned long fadelength, int playerIndex)
{
- sendsetfade(m_tqchildren[playerIndex].m_pipeB[1], fadeout, fadelength);
+ sendsetfade(m_children[playerIndex].m_pipeB[1], fadeout, fadelength);
}
void PlayerControl::addScopeBuf(struct DelayQueue *item, int playerIndex)
{
if (playerIndex >=0 && playerIndex < nNumPlayers)
{
- if (m_tqchildren[playerIndex].scopebuftail)
+ if (m_children[playerIndex].scopebuftail)
{
item->fwd = 0;
- m_tqchildren[playerIndex].scopebuftail->fwd = item;
- m_tqchildren[playerIndex].scopebuftail = item;
- m_tqchildren[playerIndex].scopecount++;
+ m_children[playerIndex].scopebuftail->fwd = item;
+ m_children[playerIndex].scopebuftail = item;
+ m_children[playerIndex].scopecount++;
}
else
{
item->fwd = 0;
- m_tqchildren[playerIndex].scopebufhead = item;
- m_tqchildren[playerIndex].scopebuftail = item;
- m_tqchildren[playerIndex].scopecount = 1;
+ m_children[playerIndex].scopebufhead = item;
+ m_children[playerIndex].scopebuftail = item;
+ m_children[playerIndex].scopecount = 1;
}
}
}
@@ -920,14 +920,14 @@ DelayQueue *PlayerControl::getScopeBuf(int playerIndex)
{
if (playerIndex >=0 && playerIndex < nNumPlayers)
{
- struct DelayQueue *item = m_tqchildren[playerIndex].scopebufhead;
+ struct DelayQueue *item = m_children[playerIndex].scopebufhead;
if (item)
{
- m_tqchildren[playerIndex].scopebufhead = item->fwd;
- m_tqchildren[playerIndex].scopecount--;
- if (!m_tqchildren[playerIndex].scopebufhead)
- m_tqchildren[playerIndex].scopebuftail = 0;
+ m_children[playerIndex].scopebufhead = item->fwd;
+ m_children[playerIndex].scopecount--;
+ if (!m_children[playerIndex].scopebufhead)
+ m_children[playerIndex].scopebuftail = 0;
}
return item;
}
@@ -937,15 +937,15 @@ DelayQueue *PlayerControl::getScopeBuf(int playerIndex)
int PlayerControl::getScopeCount(int playerIndex)
{
- return (playerIndex >= 0 && playerIndex < nNumPlayers ? m_tqchildren[playerIndex].scopecount : 0);
+ return (playerIndex >= 0 && playerIndex < nNumPlayers ? m_children[playerIndex].scopecount : 0);
}
int PlayerControl::peekScopeTime(unsigned long &t, int playerIndex)
{
if (playerIndex >=0 && playerIndex < nNumPlayers)
{
- if (m_tqchildren[playerIndex].scopebufhead)
- t = m_tqchildren[playerIndex].scopebufhead->time;
+ if (m_children[playerIndex].scopebufhead)
+ t = m_children[playerIndex].scopebufhead->time;
else
return -1;
return 0;
@@ -962,7 +962,7 @@ void PlayerControl::clearScopeQ(int playerIndex)
}
else
{
- sendscopeclear(m_tqchildren[playerIndex].m_pipeB[1]);
+ sendscopeclear(m_children[playerIndex].m_pipeB[1]);
struct DelayQueue *item;
while ((item = getScopeBuf(playerIndex)))
if (item->allocd)
@@ -976,7 +976,7 @@ void PlayerControl::enableEQ(bool enabled)
unsigned char c = (char) enabled;
for (i=0; i<nNumPlayers; i++)
- sendmessage(m_tqchildren[i].m_pipeB[1], ENABLEEQ, (unsigned char *) &c, 1);
+ sendmessage(m_children[i].m_pipeB[1], ENABLEEQ, (unsigned char *) &c, 1);
m_eq_enabled = enabled;
}
@@ -1021,7 +1021,7 @@ int PlayerControl::getMimeListLen() const
HelixSimplePlayer::metaData *PlayerControl::getMetaData(int playerIndex )
{
- return m_tqchildren[playerIndex].md;
+ return m_children[playerIndex].md;
}
bool PlayerControl::sendsetoutputsink()
@@ -1031,7 +1031,7 @@ bool PlayerControl::sendsetoutputsink()
bool ok = false;
for (i=0; i<nNumPlayers; i++)
- ok |= sendmessage(m_tqchildren[i].m_pipeB[1], OUTPUTSINK, (unsigned char *) &c, 1);
+ ok |= sendmessage(m_children[i].m_pipeB[1], OUTPUTSINK, (unsigned char *) &c, 1);
return ok;
}
@@ -1045,7 +1045,7 @@ bool PlayerControl::sendsetdevice()
bool ok = false;
for (i=0; i<nNumPlayers; i++)
- ok |= sendmessage(m_tqchildren[i].m_pipeB[1], DEVICE, (unsigned char *) m_device, len + 1);
+ ok |= sendmessage(m_children[i].m_pipeB[1], DEVICE, (unsigned char *) m_device, len + 1);
return ok;
}
@@ -1056,7 +1056,7 @@ bool PlayerControl::sendinit()
bool ok = false;
for (i=0; i<nNumPlayers; i++)
- ok |= sendrequest(m_tqchildren[i].m_pipeB[1], INIT);
+ ok |= sendrequest(m_children[i].m_pipeB[1], INIT);
return ok;
}
@@ -1077,12 +1077,12 @@ bool PlayerControl::sendupdateeqgains()
memcpy((void *)&buf[ sizeof(m_preamp) + (i+1) * sizeof(int) ], (void *) &bandGain, sizeof(int));
}
for ( i = 0; i < (uint) nNumPlayers; i++ )
- ok |= sendmessage(m_tqchildren[i].m_pipeB[1], UPDATEETQGAINS, buf, sizeof(m_preamp) + (m_equalizerGains.size()+1) * sizeof(int));
+ ok |= sendmessage(m_children[i].m_pipeB[1], UPDATEETQGAINS, buf, sizeof(m_preamp) + (m_equalizerGains.size()+1) * sizeof(int));
return ok;
}
-// tqchildren send this!
+// children send this!
bool PlayerControl::sendnotifyuser(unsigned long code, const char *moreinfo, const char *moreinfourl)
{
int len1 = strlen(moreinfo), len2 = strlen(moreinfourl), len;
@@ -1095,10 +1095,10 @@ bool PlayerControl::sendnotifyuser(unsigned long code, const char *moreinfo, con
memcpy( (void *) &buf[ len ], (void *) moreinfourl, len2 + 1);
len += len2 + 1;
- return (sendmessage(m_tqchildren[m_index].m_pipeA[1], NOTIFYUSER, buf, len));
+ return (sendmessage(m_children[m_index].m_pipeA[1], NOTIFYUSER, buf, len));
}
-// tqchildren send this!
+// children send this!
bool PlayerControl::sendinterruptuser(unsigned long code, const char *moreinfo, const char *moreinfourl)
{
int len1 = strlen(moreinfo), len2 = strlen(moreinfourl), len;
@@ -1111,21 +1111,21 @@ bool PlayerControl::sendinterruptuser(unsigned long code, const char *moreinfo,
memcpy( (void *) &buf[ len ], (void *) moreinfourl, len2 + 1);
len += len2 + 1;
- return (sendmessage(m_tqchildren[m_index].m_pipeA[1], INTERRUPTUSER, buf, len));
+ return (sendmessage(m_children[m_index].m_pipeA[1], INTERRUPTUSER, buf, len));
}
-// tqchildren send this!
+// children send this!
bool PlayerControl::sendcontacting(const char *host)
{
int len = strlen(host);
- return (sendmessage(m_tqchildren[m_index].m_pipeA[1], CONTACTING, (unsigned char *) host, len + 1));
+ return (sendmessage(m_children[m_index].m_pipeA[1], CONTACTING, (unsigned char *) host, len + 1));
}
-// tqchildren send this!
+// children send this!
bool PlayerControl::sendbuffering(int percentage)
{
- return (sendmessage(m_tqchildren[m_index].m_pipeA[1], BUFFERING, (unsigned char *) &percentage, sizeof(unsigned long)));
+ return (sendmessage(m_children[m_index].m_pipeA[1], BUFFERING, (unsigned char *) &percentage, sizeof(unsigned long)));
}
diff --git a/amarok/src/engine/kdemm/kdemmengine.cpp b/amarok/src/engine/kdemm/kdemmengine.cpp
index b39033e0..a5ea4a7a 100644
--- a/amarok/src/engine/kdemm/kdemmengine.cpp
+++ b/amarok/src/engine/kdemm/kdemmengine.cpp
@@ -27,9 +27,9 @@ what : interface to the KDE Multimedia interface (KDEMM)
#include <tqdir.h>
#include <tqdom.h>
#include <tqfile.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqstring.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <tqtimer.h>
#include <kapplication.h>
diff --git a/amarok/src/engine/mas/masengine.cpp b/amarok/src/engine/mas/masengine.cpp
index 190fce88..f515f5ec 100644
--- a/amarok/src/engine/mas/masengine.cpp
+++ b/amarok/src/engine/mas/masengine.cpp
@@ -401,7 +401,7 @@ bool MasEngine::masinit()
warning() << "MAS daemon not running. Starting! Please provide password..." << endl;
// masd seems not to be running, let's try to run it
TQCString cmdline;
- cmdline = TQFile::encodeName( KStandardDirs::findExe( TQString::tqfromLatin1( "tdesu" ) ) );
+ cmdline = TQFile::encodeName( KStandardDirs::findExe( TQString::fromLatin1( "tdesu" ) ) );
// TODO !!!hardcoded path
cmdline += " -n -f /usr/local/mas/log/mas-1.log -c ";
cmdline += "/usr/local/mas/bin/mas-launch";
diff --git a/amarok/src/engine/nmm/HostList.cpp b/amarok/src/engine/nmm/HostList.cpp
index 32fb19c8..623f2852 100644
--- a/amarok/src/engine/nmm/HostList.cpp
+++ b/amarok/src/engine/nmm/HostList.cpp
@@ -52,7 +52,7 @@ HostList::HostList( TQWidget *parent, const char *name )
setColumnAlignment( HostListItem::Video, TQt::AlignCenter );
setColumnAlignment( HostListItem::Audio, TQt::AlignCenter );
setColumnAlignment( HostListItem::Volume, TQt::AlignCenter );
- setColumnAlignment( HostListItem::tqStatus, TQt::AlignLeft );
+ setColumnAlignment( HostListItem::Status, TQt::AlignLeft );
}
HostList::~HostList()
@@ -67,8 +67,8 @@ void HostList::notifyHostError( TQString hostname, int error)
if( host->text(HostListItem::Hostname) == hostname )
{
host->setText( HostListItem::Hostname, hostname );
- host->settqStatus( error );
- host->tqrepaint();
+ host->setStatus( error );
+ host->repaint();
return;
}
++it;
@@ -101,8 +101,8 @@ void HostList::contentsMousePressEvent( TQMouseEvent *e)
}
// status column
else
- if( e->pos().x() > header()->sectionPos( HostListItem::tqStatus ) &&
- e->pos().x() < header()->sectionPos( HostListItem::tqStatus ) + header()->sectionSize( HostListItem::tqStatus ) )
+ if( e->pos().x() > header()->sectionPos( HostListItem::Status ) &&
+ e->pos().x() < header()->sectionPos( HostListItem::Status ) + header()->sectionSize( HostListItem::Status ) )
{
item->statusToolTip();
}
diff --git a/amarok/src/engine/nmm/HostListItem.cpp b/amarok/src/engine/nmm/HostListItem.cpp
index cb8e61f0..f7a8e83a 100644
--- a/amarok/src/engine/nmm/HostListItem.cpp
+++ b/amarok/src/engine/nmm/HostListItem.cpp
@@ -51,8 +51,8 @@ HostListItem::HostListItem( TQListView *parent, TQString hostname, bool audio, b
{
setText( HostListItem::Hostname, hostname);
- setPixmap( HostListItem::tqStatus, SmallIcon("info") );
- setText( HostListItem::tqStatus, i18n("Unknown") );
+ setPixmap( HostListItem::Status, SmallIcon("info") );
+ setText( HostListItem::Status, i18n("Unknown") );
setPixmap( HostListItem::Playback, SmallIcon("info") );
setText( HostListItem::Playback, i18n("Unknown") );
@@ -77,7 +77,7 @@ int HostListItem::volumeAtPosition( int x )
void HostListItem::updateColumn( int column ) const
{
- const TQRect r = listView()->tqitemRect( this );
+ const TQRect r = listView()->itemRect( this );
if( !r.isValid() )
return;
@@ -88,10 +88,10 @@ void HostListItem::updateColumn( int column ) const
void HostListItem::statusToolTip()
{
- TQWhatsThis::display( prettytqStatus( m_status ) );
+ TQWhatsThis::display( prettyStatus( m_status ) );
}
-TQString HostListItem::prettytqStatus( int error )
+TQString HostListItem::prettyStatus( int error )
{
TQString st;
@@ -146,24 +146,24 @@ void HostListItem::paintCell(TQPainter * p, const TQColorGroup & cg, int column,
if( ! m_read_only)
setPixmap( HostListItem::Audio, SmallIcon("nmm_option_off") );
}
- else if( column == HostListItem::tqStatus )
+ else if( column == HostListItem::Status )
{
TQFont font( p->font() );
if( ! m_status ) // Unknown
{
font.setBold( false );
- setText( HostListItem::tqStatus , i18n("Unknown") );
+ setText( HostListItem::Status , i18n("Unknown") );
}
else if( m_status == NmmEngine::STATUS_OK )
{
font.setBold( false );
m_cg.setColor( TQColorGroup::Text, TQt::darkGreen );
- setText( HostListItem::tqStatus , i18n("OK") );
+ setText( HostListItem::Status , i18n("OK") );
}
else { // error
font.setBold( true );
m_cg.setColor( TQColorGroup::Text, TQt::red );
- setText( HostListItem::tqStatus , i18n("Failed") );
+ setText( HostListItem::Status , i18n("Failed") );
}
p->setFont( font );
}
@@ -257,9 +257,9 @@ TQPixmap HostListItem::generateGradient( int type )
KPixmap result = TQPixmap( 113, 24 );
if( type == PixRight)
- KPixmapEffect::gradient( result, listView()->tqcolorGroup().background(), listView()->tqcolorGroup().highlight(), KPixmapEffect::HorizontalGradient );
+ KPixmapEffect::gradient( result, listView()->colorGroup().background(), listView()->colorGroup().highlight(), KPixmapEffect::HorizontalGradient );
else
- KPixmapEffect::gradient( result, listView()->tqcolorGroup().highlight(), listView()->tqcolorGroup().background(), KPixmapEffect::HorizontalGradient );
+ KPixmapEffect::gradient( result, listView()->colorGroup().highlight(), listView()->colorGroup().background(), KPixmapEffect::HorizontalGradient );
result.setMask( mask);
return result;
diff --git a/amarok/src/engine/nmm/HostListItem.h b/amarok/src/engine/nmm/HostListItem.h
index ae3c9bcd..2a3b649e 100644
--- a/amarok/src/engine/nmm/HostListItem.h
+++ b/amarok/src/engine/nmm/HostListItem.h
@@ -36,7 +36,7 @@ class HostListItem : public KListViewItem {
Video,
Audio,
Volume,
- tqStatus,
+ Status,
Playback
};
@@ -49,7 +49,7 @@ class HostListItem : public KListViewItem {
bool isAudioEnabled() const { return m_audio; }
void toggleAudio() { m_audio = !m_audio; }
- void settqStatus( int s ) { m_status = s; }
+ void setStatus( int s ) { m_status = s; }
int status() const { return m_status; }
void setVolume( int v ) { m_volume = v; }
@@ -69,7 +69,7 @@ class HostListItem : public KListViewItem {
* \todo make it user friendly/understandable
* \todo right place for this method?
*/
- static TQString prettytqStatus( int );
+ static TQString prettyStatus( int );
protected:
void paintCell( TQPainter * painter, const TQColorGroup & cg, int column, int width, int align );
diff --git a/amarok/src/engine/nmm/NmmLocation.h b/amarok/src/engine/nmm/NmmLocation.h
index 2c628602..a1bc693d 100644
--- a/amarok/src/engine/nmm/NmmLocation.h
+++ b/amarok/src/engine/nmm/NmmLocation.h
@@ -46,7 +46,7 @@ class NmmLocation {
int volume() const { return m_volume; }
void setVolume( int v ) { m_volume = v; }
- void settqStatus( int s ) { m_status = s; }
+ void setStatus( int s ) { m_status = s; }
int status() const { return m_status; }
private:
diff --git a/amarok/src/engine/nmm/nmm_configdialog.cpp b/amarok/src/engine/nmm/nmm_configdialog.cpp
index 712e98ea..e670c823 100644
--- a/amarok/src/engine/nmm/nmm_configdialog.cpp
+++ b/amarok/src/engine/nmm/nmm_configdialog.cpp
@@ -31,7 +31,7 @@
#include <tqbuttongroup.h>
#include <tqinputdialog.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlistbox.h>
#include <tqpushbutton.h>
#include <tqradiobutton.h>
diff --git a/amarok/src/engine/nmm/nmm_configdialogbase.ui b/amarok/src/engine/nmm/nmm_configdialogbase.ui
index bef5c7e0..c716be9c 100644
--- a/amarok/src/engine/nmm/nmm_configdialogbase.ui
+++ b/amarok/src/engine/nmm/nmm_configdialogbase.ui
@@ -21,7 +21,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout6</cstring>
+ <cstring>layout6</cstring>
</property>
<hbox>
<property name="name">
@@ -68,7 +68,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>16</height>
@@ -130,7 +130,7 @@ This setting will enable audio on the three hosts desktop, laptop and kitchen, a
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<hbox>
<property name="name">
@@ -159,7 +159,7 @@ This setting will enable audio on the three hosts desktop, laptop and kitchen, a
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout13</cstring>
+ <cstring>layout13</cstring>
</property>
<vbox>
<property name="name">
@@ -191,7 +191,7 @@ This setting will enable audio on the three hosts desktop, laptop and kitchen, a
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>1</height>
@@ -214,7 +214,7 @@ This setting will enable audio on the three hosts desktop, laptop and kitchen, a
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/amarok/src/engine/nmm/nmm_engine.cpp b/amarok/src/engine/nmm/nmm_engine.cpp
index 43b065de..f370974a 100644
--- a/amarok/src/engine/nmm/nmm_engine.cpp
+++ b/amarok/src/engine/nmm/nmm_engine.cpp
@@ -155,14 +155,14 @@ void NmmEngine::notifyHostError( TQString hostname, int error )
for( TQValueList<NmmLocation>::Iterator it = tmp_user_list.begin(); it != tmp_user_list.end(); ++it ) {
if( (*it).hostname() == hostname ) {
- (*it).settqStatus( error );
+ (*it).setStatus( error );
break;
}
}
for( TQValueList<NmmLocation>::Iterator it = tmp_environment_list.begin(); it != tmp_environment_list.end(); ++it ) {
if( (*it).hostname() == hostname ) {
- (*it).settqStatus( error );
+ (*it).setStatus( error );
break;
}
}
@@ -368,7 +368,7 @@ bool NmmEngine::load(const KURL& url, bool stream)
if( NmmKDEConfig::location() == NmmKDEConfig::EnumLocation::LocalhostOnly )
{
m_localhostonly_errordialog = true;
- TQString detailed_status = HostListItem::prettytqStatus( error );
+ TQString detailed_status = HostListItem::prettyStatus( error );
KMessageBox::detailedError( 0, i18n("Local NMM playback failed."), detailed_status, i18n("Error"), KMessageBox::AllowLink );
m_localhostonly_errordialog = false;
}
diff --git a/amarok/src/engine/nmm/nmm_engine.h b/amarok/src/engine/nmm/nmm_engine.h
index 2b78b610..f2238fef 100644
--- a/amarok/src/engine/nmm/nmm_engine.h
+++ b/amarok/src/engine/nmm/nmm_engine.h
@@ -245,7 +245,7 @@ private:
static NmmEngine* s_instance;
public:
- enum HosttqStatus {
+ enum HostStatus {
STATUS_UNKNOWN = 0,
STATUS_OK = 1 << 0,
ERROR_PLAYBACKNODE = 1 << 1,
diff --git a/amarok/src/engine/xine/xine-engine.cpp b/amarok/src/engine/xine/xine-engine.cpp
index 581923be..48353ac3 100644
--- a/amarok/src/engine/xine/xine-engine.cpp
+++ b/amarok/src/engine/xine/xine-engine.cpp
@@ -801,7 +801,7 @@ XineEngine::customEvent( TQCustomEvent *e )
break;
case 3001:
- emit infoMessage( (*message).tqarg( m_url.prettyURL() ) );
+ emit infoMessage( (*message).arg( m_url.prettyURL() ) );
delete message;
break;
@@ -818,7 +818,7 @@ XineEngine::customEvent( TQCustomEvent *e )
} break;
case 3004:
- emit statusText( i18n("Redirecting to: ").tqarg( *message ) );
+ emit statusText( i18n("Redirecting to: ").arg( *message ) );
load( KURL( *message ), false );
play();
delete message;
@@ -923,8 +923,8 @@ XineEngine::XineEventListener( void *p, const xine_event_t* xineEvent )
TQString
msg = "%1 %2%";
- msg = msg.tqarg( TQString::fromUtf8( pd->description ) )
- .tqarg( KGlobal::locale()->formatNumber( pd->percent, 0 ) );
+ msg = msg.arg( TQString::fromUtf8( pd->description ) )
+ .arg( KGlobal::locale()->formatNumber( pd->percent, 0 ) );
TQCustomEvent *e = new TQCustomEvent( 3002 );
e->setData( new TQString( msg ) );
@@ -1102,7 +1102,7 @@ bool XineEngine::metaDataForUrl(const KURL &url, Engine::SimpleMetaBundle &b)
if( b.tracknr.isEmpty() )
b.tracknr = url.filename();
} else {
- b.title = TQString(i18n("Track %1")).tqarg(url.filename());
+ b.title = TQString(i18n("Track %1")).arg(url.filename());
b.album = i18n("AudioCD");
}
}
diff --git a/amarok/src/engine/xine/xineconfigbase.ui b/amarok/src/engine/xine/xineconfigbase.ui
index a280f3e3..50e87bbf 100644
--- a/amarok/src/engine/xine/xineconfigbase.ui
+++ b/amarok/src/engine/xine/xineconfigbase.ui
@@ -32,7 +32,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout11</cstring>
+ <cstring>layout11</cstring>
</property>
<hbox>
<property name="name">
@@ -68,13 +68,13 @@
<property name="text">
<string></string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout10</cstring>
+ <cstring>layout10</cstring>
</property>
<vbox>
<property name="name">
@@ -82,7 +82,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout10</cstring>
+ <cstring>layout10</cstring>
</property>
<vbox>
<property name="name">
@@ -90,7 +90,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -129,7 +129,7 @@
<property name="text">
<string>Sound device may be modified after the output plugin has been changed to ALSA or OSS.</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
@@ -241,7 +241,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<hbox>
<property name="name">
@@ -278,7 +278,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<hbox>
<property name="name">
@@ -318,7 +318,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -376,7 +376,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout11</cstring>
+ <cstring>layout11</cstring>
</property>
<vbox>
<property name="name">
@@ -419,7 +419,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout12</cstring>
+ <cstring>layout12</cstring>
</property>
<vbox>
<property name="name">
@@ -435,7 +435,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout10</cstring>
+ <cstring>layout10</cstring>
</property>
<hbox>
<property name="name">
@@ -486,7 +486,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/amarok/src/engine/yauap/yauap-engine.cpp b/amarok/src/engine/yauap/yauap-engine.cpp
index e9fef143..b3e8f0cd 100644
--- a/amarok/src/engine/yauap/yauap-engine.cpp
+++ b/amarok/src/engine/yauap/yauap-engine.cpp
@@ -646,7 +646,7 @@ yauapEngine::getAudioCDContents(const TQString &device, KURL::List &urls)
KURL url = TQString(TQString("cdda://").append( strtok_r(reply_ptr,"=",&saveptr)));
urls << url;
debug() << url << endl;
- b.title = TQString( i18n( "Track %1" ) ).tqarg( i+1 );
+ b.title = TQString( i18n( "Track %1" ) ).arg( i+1 );
b.length = strtok_r(NULL,"=",&saveptr);
b.album = "AudioCD";
b.tracknr = i+1;
diff --git a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxcore.h b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxcore.h
index 6789f26f..4d6d7178 100644
--- a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxcore.h
+++ b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxcore.h
@@ -224,7 +224,7 @@ DECLARE_INTERFACE_(IHXStream, IUnknown)
/************************************************************************
* Method:
- * IHXStream::ReportRebuffertqStatus
+ * IHXStream::ReportRebufferStatus
* Purpose:
* Call this method to report to the playback context that the
* available data has dropped to a critically low level, and that
@@ -235,12 +235,12 @@ DECLARE_INTERFACE_(IHXStream, IUnknown)
* NOTE: The values of unNeeded and unAvailable are used to indicate
* the general status of the rebuffering effort. For example, if a
* renderer has "run dry" and needs 5 data packets to play smoothly
* again, it should call ReportRebuffertqStatus() with 5,0 then as
* packet arrive it should call again with 5,1; 5,2... and eventually
* 5,5.
*
*/
- STDTQT_METHOD(ReportRebuffertqStatus) (THIS_
+ STDTQT_METHOD(ReportRebufferStatus) (THIS_
UINT8 unNeeded,
UINT8 unAvailable) PURE;
@@ -302,20 +302,20 @@ DECLARE_INTERFACE_(IHXStream2, IHXStream)
{
/************************************************************************
* Method:
- * IHXStream2::ReportAudioRebuffertqStatus
+ * IHXStream2::ReportAudioRebufferStatus
* Purpose:
* For audio only, when it's called, the rebuffer will only occur when
* there aren't any packets in the transport and the amount of audio in
* audio device falls below the minimum startup audio pushdown(1000ms
* by default)
*
* Non-audio renderers should still call ReportRebuffertqStatus(), the
* rebuffer will occur when the core drains out all the packets from
* the transport buffer
*
* The rest semantic are the same between the 2 calls.
*/
- STDTQT_METHOD(ReportAudioRebuffertqStatus) (THIS_
+ STDTQT_METHOD(ReportAudioRebufferStatus) (THIS_
UINT8 unNeeded,
UINT8 unAvailable) PURE;
};
@@ -1129,7 +1129,7 @@ DECLARE_INTERFACE_(IHXLayoutStream, IUnknown)
* Method:
* IHXLayoutStream::GetProperty
* Purpose:
- * Get tqlayout stream property
+ * Get layout stream property
*
*
*/
@@ -1140,7 +1140,7 @@ DECLARE_INTERFACE_(IHXLayoutStream, IUnknown)
* Method:
* IHXLayoutStream::SetProperty
* Purpose:
- * Set tqlayout stream property
+ * Set layout stream property
*
*/
STDTQT_METHOD(SetProperties) (THIS_
@@ -235,12 +235,12 @@ DECLARE_INTERFACE_(IHXStream, IUnknown)
* the general status of the rebuffering effort. For example, if a
* renderer has "run dry" and needs 5 data packets to play smoothly
- * again, it should call ReportRebuffertqStatus() with 5,0 then as
+ * again, it should call ReportRebufferStatus() with 5,0 then as
* packet arrive it should call again with 5,1; 5,2... and eventually
* 5,5.
@@ -302,20 +302,20 @@ DECLARE_INTERFACE_(IHXStream2, IHXStream)
* by default)
*
- * Non-audio renderers should still call ReportRebuffertqStatus(), the
+ * Non-audio renderers should still call ReportRebufferStatus(), the
* rebuffer will occur when the core drains out all the packets from
* the transport buffer
diff --git a/amarok/src/engine/helix/hxplayercontrol.h b/amarok/src/engine/helix/hxplayercontrol.h
index 37b0a121..8ccdd445 100644
--- a/amarok/src/engine/helix/hxplayercontrol.h
+++ b/amarok/src/engine/helix/hxplayercontrol.h
@@ -87,7 +87,7 @@ public:
virtual void onContacting(const char */*host*/) {}
virtual void onBuffering(int /*percentage*/) {}
// tqchildren send functions
bool sendnotifyuser(unsigned long code, const char *moreinfo, const char *moreinfourl);
bool sendinterruptuser(unsigned long code, const char *moreinfo, const char *moreinfourl);
bool sendcontacting(const char *host);
@@ -129,7 +129,7 @@ private:
DelayQueue *q;
int *m_current;
int *m_consumed;
- } m_tqchildren[2];
+ } m_children[2];
unsigned long m_volume;
@@ -87,7 +87,7 @@ public:
virtual void onContacting(const char */*host*/) {}
virtual void onBuffering(int /*percentage*/) {}
- // tqchildren send functions
+ // children send functions
bool sendnotifyuser(unsigned long code, const char *moreinfo, const char *moreinfourl);
bool sendinterruptuser(unsigned long code, const char *moreinfo, const char *moreinfourl);